Try isort from your browser! ======== Use our live isort editor to see how isort can help improve the formatting of your Python imports. !!! important - "Safe to use. No code is transmitted." The below live isort tester doesn't transmit any of the code you paste to our server or anyone else's. Instead, this page runs a complete Python3 installation with isort installed entirely within your browser. To accomplish this, it utilizes the [pyodide](https://github.com/iodide-project/pyodide) project.
from future import braces import b import b import os import a from future import braces import b import a import b, a
Loading...
Configuration (Note: the below must follow JSON format). Full configuration guide is here:
{"line_length": 80, "profile": "black", "atomic": true }
Like what you saw? Installing isort to use locally is as simple as `pip3 install isort`. [Click here for full installation instructions.](https://pycqa.github.io/isort/docs/quick_start/1.-install)